==> ejc-zjkjcost-impl-3.0.0-20220628.083136-18-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeGrantDetailEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节点考核-节点目标奖金考核发放-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_node_grant_detail")
public class NodeGrantDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 经办人
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 经办人名称
    @TableField(value="detail_department_id")
    private Long detailDepartmentId; // 经办部门
    @TableField(value="detail_department_name")
    private String detailDepartmentName; // 经办部门名称
    @TableField(value="detail_distribution_mny")
    private BigDecimal detailDistributionMny; // 分配金额
    @TableField(value="detail_actual_mny")
    private BigDecimal detailActualMny; // 实发金额
    @TableField(value="distribution_sign")
    private String distributionSign; // 分配人签字
    @TableField(value="souce_type")
    private Integer souceType; // 来源类型（0：新增，1：导入）
    @TableField(value="source_type_name")
    private String sourceTypeName; // 来源类型名称
    @TableField(value="grant_id")
    private Long grantId; // 主表id
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_name")
    private String sourceName; // 来源名称
    
    
    

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public Long getDetailDepartmentId() {
        return detailDepartmentId;
    }

    public void setDetailDepartmentId(Long detailDepartmentId) {
        this.detailDepartmentId = detailDepartmentId;
    }
    public String getDetailDepartmentName() {
        return detailDepartmentName;
    }

    public void setDetailDepartmentName(String detailDepartmentName) {
        this.detailDepartmentName = detailDepartmentName;
    }
    public BigDecimal getDetailDistributionMny() {
        return detailDistributionMny;
    }

    public void setDetailDistributionMny(BigDecimal detailDistributionMny) {
        this.detailDistributionMny = detailDistributionMny;
    }
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    public String getDistributionSign() {
        return distributionSign;
    }

    public void setDistributionSign(String distributionSign) {
        this.distributionSign = distributionSign;
    }
    public Integer getSouceType() {
        return souceType;
    }

    public void setSouceType(Integer souceType) {
        this.souceType = souceType;
    }
    public String getSourceTypeName() {
        return sourceTypeName;
    }

    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }
    public Long getGrantId() {
        return grantId;
    }

    public void setGrantId(Long grantId) {
        this.grantId = grantId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20220711.032004-35-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeGrantDetailEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节点考核-节点目标奖金考核发放-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_node_grant_detail")
public class NodeGrantDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 经办人
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 经办人名称
    @TableField(value="detail_department_id")
    private Long detailDepartmentId; // 经办部门
    @TableField(value="detail_department_name")
    private String detailDepartmentName; // 经办部门名称
    @TableField(value="detail_distribution_mny")
    private BigDecimal detailDistributionMny; // 分配金额
    @TableField(value="detail_actual_mny")
    private BigDecimal detailActualMny; // 实发金额
    @TableField(value="distribution_sign")
    private String distributionSign; // 分配人签字
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型（0：新增，1：导入）
    @TableField(value="source_type_name")
    private String sourceTypeName; // 来源类型名称
    @TableField(value="grant_id")
    private Long grantId; // 主表id
    @TableField(value="source_id")
    private Long sourceId; // 来源id
    @TableField(value="source_name")
    private String sourceName; // 来源名称
    
    
    

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public Long getDetailDepartmentId() {
        return detailDepartmentId;
    }

    public void setDetailDepartmentId(Long detailDepartmentId) {
        this.detailDepartmentId = detailDepartmentId;
    }
    public String getDetailDepartmentName() {
        return detailDepartmentName;
    }

    public void setDetailDepartmentName(String detailDepartmentName) {
        this.detailDepartmentName = detailDepartmentName;
    }
    public BigDecimal getDetailDistributionMny() {
        return detailDistributionMny;
    }

    public void setDetailDistributionMny(BigDecimal detailDistributionMny) {
        this.detailDistributionMny = detailDistributionMny;
    }
    public BigDecimal getDetailActualMny() {
        return detailActualMny;
    }

    public void setDetailActualMny(BigDecimal detailActualMny) {
        this.detailActualMny = detailActualMny;
    }
    public String getDistributionSign() {
        return distributionSign;
    }

    public void setDistributionSign(String distributionSign) {
        this.distributionSign = distributionSign;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getSourceTypeName() {
        return sourceTypeName;
    }

    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }
    public Long getGrantId() {
        return grantId;
    }

    public void setGrantId(Long grantId) {
        this.grantId = grantId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceName() {
        return sourceName;
    }

    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
    
}
